(function ($, Drupal, drupalSettings) {
  Drupal.behaviors.idealyzerChartBehavior = {
    attach: function (context, settings) {
      $(document).ready(function () {
        var canvas = document.getElementById("cmsChart");
        if (canvas) {
          var ctx = canvas.getContext("2d");
          var cmsData = drupalSettings.cmsChartData;

          // Define a color mapping for each CMS value
          var colorMapping = {
            'wordpress': "#36a2eb",
            'drupal': "#ff6384",
            'microsoft sharepoint': "#ffce56",
            'cloud.gov pages': "#4bc0c0",
            'joomla': "#9966ff",
            'na': "#cccccc"
          };

          // Define a display name mapping for correctly capitalized CMS names
          var displayNameMapping = {
            'wordpress': 'WordPress',
            'drupal': 'Drupal',
            'microsoft sharepoint': 'Microsoft SharePoint',
            'cloud.gov pages': 'cloud.gov Pages',
            'joomla': 'Joomla',
            'na': 'Unknown'
          };

          var labels = Object.keys(cmsData).map(function(cms) {
            return displayNameMapping[cms] || cms;
          });

          var data = Object.values(cmsData);

          var backgroundColors = Object.keys(cmsData).map(function(cms) {
            return colorMapping[cms] || "#cccccc"; // Default color if not found in mapping
          });

          new Chart(ctx, {
            type: "pie",
            data: {
              labels: labels,
              datasets: [{
                data: data,
                backgroundColor: backgroundColors
              }]
            },
            options: {
              responsive: true,
              maintainAspectRatio: false,
              title: {
                display: true,
                text: "CMS Distribution"
              }
            }
          });
        } else {
          console.error("Canvas element not found");
        }
      });
    }
  };
})(jQuery, Drupal, drupalSettings);
